import { IgrColorScale } from "./igr-color-scale";
import { IgrScatterTriangulationSeries } from "./igr-scatter-triangulation-series";
import { ScatterAreaSeries } from "./ScatterAreaSeries";
import { toPoint } from "igniteui-react-core";
/**
 * Series class which draws a colored 2D surface based on a triangulation of XY data with numeric values assigned to each point.
*/
export class IgrScatterAreaSeries extends IgrScatterTriangulationSeries {
    createImplementation() {
        return new ScatterAreaSeries();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets whether the current series shows an area shape.
    */
    get isArea() {
        return this.i.c7;
    }
    /**
     * Gets or sets ColorScale used to resolve the color values of points in the series.
    */
    get colorScale() {
        if (this.i.q3 == null) {
            return null;
        }
        if (!this.i.q3.externalObject) {
            let e = IgrColorScale._createFromInternal(this.i.q3);
            if (e) {
                e._implementation = this.i.q3;
            }
            this.i.q3.externalObject = e;
        }
        return this.i.q3.externalObject;
    }
    set colorScale(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.q3 = null : this.i.q3 = v.i;
    }
    /**
     * Gets or sets the name of the property on each data item containing a numeric value which can be converted to a color by the ColorScale.
    */
    get colorMemberPath() {
        return this.i.rb;
    }
    set colorMemberPath(v) {
        this.i.rb = v;
    }
    /**
     * Gets actual color scale that is set on ColorScale property or default ColorScale
    */
    get actualColorScale() {
        if (this.i.q2 == null) {
            return null;
        }
        if (!this.i.q2.externalObject) {
            let e = IgrColorScale._createFromInternal(this.i.q2);
            if (e) {
                e._implementation = this.i.q2;
            }
            this.i.q2.externalObject = e;
        }
        return this.i.q2.externalObject;
    }
    set actualColorScale(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.q2 = null : this.i.q2 = v.i;
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.colorScale && this.colorScale.name && this.colorScale.name == name) {
            return this.colorScale;
        }
        if (this.actualColorScale && this.actualColorScale.name && this.actualColorScale.name == name) {
            return this.actualColorScale;
        }
        return null;
    }
    _styling(container, component, parent) {
        super._styling(container, component, parent);
        this._inStyling = true;
        if (this.colorScale && this.colorScale._styling) {
            this.colorScale._styling(container, component, this);
        }
        if (this.actualColorScale && this.actualColorScale._styling) {
            this.actualColorScale._styling(container, component, this);
        }
        this._inStyling = false;
    }
    getItemValue(item, memberPathName) {
        let iv = this.i.hk(item, memberPathName);
        return (iv);
    }
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world) {
        let iv = this.i.hh(toPoint(world));
        return (iv);
    }
    /**
     * Updates ActualColorScale properties when the ColorScale property has changed
    
    */
    updateActualColorScale() {
        this.i.ri();
    }
    /**
     * Attaches an image to the view of this series
    
    */
    attachImage(image) {
        this.i.rf(image);
    }
}
//# sourceMappingURL=igr-scatter-area-series.js.map
