import { __extends } from "tslib";
import { IgrValueBrushScale } from "./igr-value-brush-scale";
import { IgrContourValueResolver } from "./igr-contour-value-resolver";
import { IgrScatterTriangulationSeries } from "./igr-scatter-triangulation-series";
import { ScatterContourSeries } from "./ScatterContourSeries";
/**
 * Series class for rendering isarithmic contours based on a triangulation of X+Y+Value points in the ItemsSource.
*/
var IgrScatterContourSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrScatterContourSeries, _super);
    function IgrScatterContourSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrScatterContourSeries.prototype.createImplementation = function () {
        return new ScatterContourSeries();
    };
    Object.defineProperty(IgrScatterContourSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrScatterContourSeries.prototype, "isLineContour", {
        /**
         * Gets whether the current series shows a line contour shape.
        */
        get: function () {
            return this.i.du;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrScatterContourSeries.prototype, "valueMemberPath", {
        /**
         * Gets or set the name of the property from which to retrieve the numeric values from the ItemsSource items.
        */
        get: function () {
            return this.i.q9;
        },
        set: function (v) {
            this.i.q9 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrScatterContourSeries.prototype, "fillScale", {
        /**
         * Gets or sets the ValueBrushScale to use when determining Brushes for each contour line, based on the values found in ValueMemberPath.
        */
        get: function () {
            if (this.i.q3 == null) {
                return null;
            }
            if (!this.i.q3.externalObject) {
                var e = IgrValueBrushScale._createFromInternal(this.i.q3);
                if (e) {
                    e._implementation = this.i.q3;
                }
                this.i.q3.externalObject = e;
            }
            return this.i.q3.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.q3 = null : this.i.q3 = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrScatterContourSeries.prototype, "actualFillScale", {
        /**
         * Gets actual fill scale that is set on the FillScale property or default FillScale
        */
        get: function () {
            if (this.i.q2 == null) {
                return null;
            }
            if (!this.i.q2.externalObject) {
                var e = IgrValueBrushScale._createFromInternal(this.i.q2);
                if (e) {
                    e._implementation = this.i.q2;
                }
                this.i.q2.externalObject = e;
            }
            return this.i.q2.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.q2 = null : this.i.q2 = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrScatterContourSeries.prototype, "valueResolver", {
        /**
         * Gets or set the ContourValueResolver used to determine the numeric values of contours.
        */
        get: function () {
            if (this.i.q0 == null) {
                return null;
            }
            if (!this.i.q0.externalObject) {
                var e = IgrContourValueResolver._createFromInternal(this.i.q0);
                if (e) {
                    e._implementation = this.i.q0;
                }
                this.i.q0.externalObject = e;
            }
            return this.i.q0.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.q0 = null : this.i.q0 = v.i;
        },
        enumerable: false,
        configurable: true
    });
    IgrScatterContourSeries.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.fillScale && this.fillScale.name && this.fillScale.name == name) {
            return this.fillScale;
        }
        if (this.actualFillScale && this.actualFillScale.name && this.actualFillScale.name == name) {
            return this.actualFillScale;
        }
        if (this.valueResolver && this.valueResolver.name && this.valueResolver.name == name) {
            return this.valueResolver;
        }
        return null;
    };
    IgrScatterContourSeries.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.fillScale && this.fillScale._styling) {
            this.fillScale._styling(container, component, this);
        }
        if (this.actualFillScale && this.actualFillScale._styling) {
            this.actualFillScale._styling(container, component, this);
        }
        if (this.valueResolver && this.valueResolver._styling) {
            this.valueResolver._styling(container, component, this);
        }
        this._inStyling = false;
    };
    IgrScatterContourSeries.prototype.getItemValue = function (item, memberPathName) {
        var iv = this.i.hk(item, memberPathName);
        return (iv);
    };
    return IgrScatterContourSeries;
}(IgrScatterTriangulationSeries));
export { IgrScatterContourSeries };
//# sourceMappingURL=igr-scatter-contour-series.js.map
